/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-AE
  * @brief          : Main program body
  *    
  *          This file provides example code for USART sync mode write and read 
  * W25Q128JV,printf by uart,LED1 blink by sysTick soft timer,if write and read
  * success LED blink period 1S, ERROR LED blink period 0.25 S.
  * For details, see "readme.txt"   
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */  
  
#include "system_define.h"

#define LED_BLINK_HALF_PER        500       // unit ms,LED blink half cycle

ErrorStatus test_result=ERROR;

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void) 
{
  ErrorStatus test_result = SUCCESS; 
  uint32_t LED_blink_Time = LED_BLINK_HALF_PER;
  uint32_t count=0;
  
  sysclk_init();                  //sysclk 48M,HSI/2 *12;if not call this function,default HSI 8M
  SystemCoreClockUpdate();
  
  sys_tick_init();
  gpio_init();
  usart1_sync_init(USART_SYNC_CK);
  virtualUart_Init();

  LED1_ON(); 
  
  printf("\r\n\r\n*****USART W25Q128 Example*****");
  printf("\r\n--Inf:System Core Clock %d Hz.",SystemCoreClock);
  
  test_result=spi_flash_test(SPI_FLASH_TEST_ADDRESS);
  if(test_result == ERROR) {
    LED_blink_Time = LED_blink_Time >>2;              // SPI Flash test ERROR LED blink fast
  }
 
  Start_User_MS_SF_Timer(LED_blink_Time);
  while(1) {
    if(Get_State_User_MS_SF_Timer() == SF_TIMER_OV) {
      Start_User_MS_SF_Timer(LED_blink_Time);         // clear soft timer ov
      
      LED1_TOGGLE();                                  // led blink for running
      count++;
      printf("\r\n--Inf: running count:%d",count);
    }
  }
}

/**
  * @brief  SystemClock_Config HSI/2 to PLL*12 sysclk 48M
  * @param  None
  * @retval None
  */
void sysclk_init(void) {
  MS32_RCC_OscInitTypeDef osc_cfg;
  MS32_RCC_PllInitTypeDef pll_cfg;
  MS32_RCC_ClkInitTypeDef clk_cfg;

  // get and clear reset flag 
  MS32_RCC_GetResetFlag(ENABLE);
  
  // osc config 
  osc_cfg.HSIState = MS32_RCC_HSI_ON;
  osc_cfg.HSEState = MS32_RCC_HSE_OFF;
  osc_cfg.LSIState = MS32_RCC_LSI_OFF;
//  osc_cfg.LSEState = MS32_RCC_LSE_ON_DRV_H;
  MS32_RCC_OscConfig(&osc_cfg);
  
  // pll config 
  pll_cfg.PLLState  = MS32_RCC_PLL_ON;
  pll_cfg.PLLSource = MS32_RCC_PLL_SOURCE_HSI_DIV_2;  // HSI/2 4M
  pll_cfg.PLLMUL    = MS32_RCC_PLL_MUL12;
  pll_cfg.PREDIV    = MS32_RCC_PLL_PREDIV_DIV1;
  MS32_RCC_PllConfig(&pll_cfg);
  
  // sysclk config 
  clk_cfg.SYSCLKSource   = MS32_RCC_SYSCLK_SOURCE_PLL;
  clk_cfg.AHBCLKDivider  = MS32_RCC_SYSCLK_DIV1;
  clk_cfg.APB1CLKDivider = MS32_RCC_HCLK_DIV1;
  MS32_RCC_ClockConfig(&clk_cfg);
}
/******************************** END OF FILE *********************************/
