/**
  ******************************************************************************
  * @file     USART1_CFG.c
  * @author   sinomcu.com-AE
  * @brief    USART1 config
  *    
  *          This file provides functions to usart1 initialization:
  *              PA2   --> USART1_TX
  *              PA3   <-- USART1_RX
  *          BaudRate:115200,8 bit,NONE,STOP 1bit
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */

#include "stdio.h"   
#include "USART1_CFG.h"

/**
  * @brief  uart IO Initialization
  *    PA2   --> USART1_TX
  *    PA3   <-- USART1_RX
  *    PA4   <-- USART1_CK
  *    PA15      GPIO for CS
  * @param  None
  * @retval None
  */
void uart_gpio_init(void) {
  MS32_GPIO_InitTypeDef GpioInitStruct = {0};

  // PA2   --> USART1_TX
  // PA3   <-- USART1_RX
  // PA4   <-- USART1_CK
  MS32_GPIO_StructInit(&GpioInitStruct);    
  GpioInitStruct.Pin = MS32_GPIO_PIN_2 |MS32_GPIO_PIN_3 |MS32_GPIO_PIN_4;
  GpioInitStruct.Mode = MS32_GPIO_MODE_ALTERNATE;
  GpioInitStruct.Speed = MS32_GPIO_SPEED_FREQ_HIGH;
  GpioInitStruct.OutputType = MS32_GPIO_OUTPUT_PUSHPULL;
  GpioInitStruct.Pull = MS32_GPIO_PULL_UP;
  GpioInitStruct.Alternate = MS32_GPIO_AF_1;
  MS32_GPIO_Init(GPIOA, &GpioInitStruct);                  // init function had enable clock

  // PA15 GPIO out pullhgih for chip selcet
  MS32_GPIO_StructInit(&GpioInitStruct);  
  GpioInitStruct.Pin = SPICS_Pin;
  GpioInitStruct.Mode = MS32_GPIO_MODE_OUTPUT;
  GpioInitStruct.OutputType = MS32_GPIO_OUTPUT_PUSHPULL;
  GpioInitStruct.Speed = MS32_GPIO_SPEED_HIGH;
  GpioInitStruct.Pull = MS32_GPIO_PULL_UP;
  GpioInitStruct.Alternate = MS32_GPIO_AF_0;
  MS32_GPIO_Init(SPICS_GPIO_Port,&GpioInitStruct);
}

/**
  * @brief  uart1 Initialization Function
  * @param  uint32_t baudrate
  * @retval None
  */
void usart1_sync_init(uint32_t baudrate) {
  MS32_USART_InitTypeDef UsartInitStruct = {0};
  MS32_USART_ClockInitTypeDef usartClockInitStruct ={0};

  uart_gpio_init();
  
  // UART parameter configuration
  MS32_USART_StructInit(&UsartInitStruct);
  UsartInitStruct.BaudRate = baudrate;
  UsartInitStruct.DataWidth = MS32_USART_DATAWIDTH_8B;
  UsartInitStruct.StopBits = MS32_USART_STOPBITS_1;
  UsartInitStruct.Parity = MS32_USART_PARITY_NONE;
  UsartInitStruct.TransferDirection = MS32_USART_DIRECTION_TX_RX;
  UsartInitStruct.HardwareFlowControl = MS32_USART_HWCONTROL_NONE;
  UsartInitStruct.OverSampling = MS32_USART_OVERSAMPLING_16;
  MS32_USART_Init(USART1, &UsartInitStruct);               // init function had enable clock
  
  MS32_USART_ClockStructInit(&usartClockInitStruct);
  usartClockInitStruct.ClockOutput =MS32_USART_CLOCK_ENABLE;
  usartClockInitStruct.ClockPolarity =MS32_USART_PHASE_1EDGE;
  usartClockInitStruct.ClockPhase =MS32_USART_POLARITY_LOW;
  usartClockInitStruct.LastBitClockPulse =MS32_USART_LASTCLKPULSE_OUTPUT;
  MS32_USART_ClockInit(USART1, &usartClockInitStruct);

  MS32_USART_SetTransferBitOrder(USART1, MS32_USART_BITORDER_MSBFIRST);
	
	
  MS32_USART_DisableIT_CTS(USART1);
  MS32_USART_ConfigSyncMode(USART1);
  MS32_USART_Enable(USART1);
}

/******************************** END OF FILE *********************************/
